@@ -1,6 +1,6 @@
 package Facebook::Graph;
-$Facebook::Graph::VERSION = '1.0801';
-use Any::Moose;
+$Facebook::Graph::VERSION = '1.0900';
+use Moo;
 use MIME::Base64::URLSafe;
 use JSON;
 use Facebook::Graph::AccessToken;
@@ -339,9 +339,7 @@ sub rsvp_declined {
 }
 
 
-
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+1;
 
 =head1 NAME
 
@@ -349,7 +347,7 @@ Facebook::Graph - A fast and easy way to integrate your apps with Facebook.
 
 =head1 VERSION
 
-version 1.0801
+version 1.0900
 
 =head1 SYNOPSIS
 
@@ -657,7 +655,7 @@ I still need to add publishing albums/photos, deleting of content, impersonation
 
 =head1 PREREQS
 
-L<Any::Moose>
+L<Moo>
 L<JSON>
 L<AnyEvent::HTTP::LWP::UserAgent>
 L<URI>
