@@ -1,6 +1,6 @@
 package Facebook::Graph::Publish::Comment;
-$Facebook::Graph::Publish::Comment::VERSION = '1.0801';
-use Any::Moose;
+$Facebook::Graph::Publish::Comment::VERSION = '1.0900';
+use Moo;
 extends 'Facebook::Graph::Publish';
 
 use constant object_path => '/comments';
@@ -28,9 +28,7 @@ around get_post_params => sub {
 };
 
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
+1;
 
 =head1 NAME
 
@@ -38,7 +36,7 @@ Facebook::Graph::Publish::Comment - Publish a comment on a post.
 
 =head1 VERSION
 
-version 1.0801
+version 1.0900
 
 =head1 SYNOPSIS
 
