@@ -1,6 +1,6 @@
 package Facebook::Graph::Publish::Link;
-$Facebook::Graph::Publish::Link::VERSION = '1.0801';
-use Any::Moose;
+$Facebook::Graph::Publish::Link::VERSION = '1.0900';
+use Moo;
 extends 'Facebook::Graph::Publish';
 
 use constant object_path => '/links';
@@ -42,9 +42,7 @@ around get_post_params => sub {
 };
 
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
-
+1;
 
 =head1 NAME
 
@@ -52,7 +50,7 @@ Facebook::Graph::Publish::Link - Add a link.
 
 =head1 VERSION
 
-version 1.0801
+version 1.0900
 
 =head1 SYNOPSIS
 
