@@ -1,6 +1,6 @@
 package Facebook::Graph::Publish::PageTab;
-$Facebook::Graph::Publish::PageTab::VERSION = '1.0801';
-use Any::Moose;
+$Facebook::Graph::Publish::PageTab::VERSION = '1.0900';
+use Moo;
 extends 'Facebook::Graph::Publish';
 
 use constant object_path => '/tabs';
@@ -17,8 +17,7 @@ around get_post_params => sub {
     return $post;
 };
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+1;
 
 
 =head1 NAME
@@ -27,7 +26,7 @@ Facebook::Graph::Publish::PageTab - Add a page tab.
 
 =head1 VERSION
 
-version 1.0801
+version 1.0900
 
 =head1 SYNOPSIS
 
