@@ -1,6 +1,6 @@
 package Facebook::Graph::Publish::Photo;
-$Facebook::Graph::Publish::Photo::VERSION = '1.0801';
-use Any::Moose;
+$Facebook::Graph::Publish::Photo::VERSION = '1.0900';
+use Moo;
 extends 'Facebook::Graph::Publish';
 
 use constant object_path => '/photos';
@@ -56,8 +56,7 @@ around get_post_params => sub {
     return $self->has_url ? $post : ( Content_Type => 'form-data', Content => $post );
 };
 
-no Any::Moose;
-__PACKAGE__->meta->make_immutable;
+1;
 
 =head1 NAME
 
@@ -65,7 +64,7 @@ Facebook::Graph::Publish::Photo - Publish Photos
 
 =head1 VERSION
 
-version 1.0801
+version 1.0900
 
 =head1 SYNOPSIS
 
